# PROCESSADOR DE IMAGENS VIRTUAIS WSC

## Descrição

Projeto processador de imagens realizado no bootcamp Geração Tech Unimed-BH Ciência de Dados na Digital Innovation One (DIO).

O processamento da imagem do pacote e usado para:

```bash
Em processador:
	- Correspondencia de histograma
	- Semelhanca estrutural
	- Redimensionar imagem

Util:
	- Ler imagem
	- Salvar imagem
	- Plotar imagem
	- Resultado da trama
	- Plotar histograma
```

## Instalação

Utilize o gerenciador de pacotes [pip](https://pip.pypa.io/en/stable/) para instalar processador-imagens-wsc

```bash
pip install processador_imagens_wsc
```

## Autor
Willian Coutinho

## License
[MIT](https://choosealicense.com/licenses/mit/)